@@ -549,6 +549,8 @@ class Drift(object):
             module, device = device.split('.')
             return self.modules[module].devices[device]
 
+        device = device.lower()
+
         dev_to_mod = defaultdict(list)
         for module in self.modules:
             for dev in self.modules[module].devices:
@@ -581,6 +583,11 @@ class Drift(object):
 
         return await self.get_device(name).read(adapt=adapt)
 
+    async def read(self, *args, **kwargs):
+        """Alias for `.read_device`."""
+
+        return await self.read_device(*args, **kwargs)
+
     async def read_category(self, category, adapt=True):
         """Reads all the devices of a given category.
 
